import MediaAccessibility
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestMAAudibleMedia(TestCase):
    @min_os_level("10.10")
    def testFunctions10_10(self):
        self.assertResultIsCFRetained(
            MediaAccessibility.MAAudibleMediaCopyPreferredCharacteristics
        )

        a = MediaAccessibility.MAAudibleMediaCopyPreferredCharacteristics()
        self.assertIsInstance(a, (MediaAccessibility.NSArray, type(None)))

    @min_os_level("10.10")
    def test_constants(self):
        self.assertIsInstance(
            MediaAccessibility.kMAAudibleMediaSettingsChangedNotification, str
        )

    @min_os_level("10.10")
    def test_constants10_10(self):
        self.assertIsInstance(
            MediaAccessibility.MAMediaCharacteristicDescribesVideoForAccessibility, str
        )



# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:41:04 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$MAMediaCharacteristicDescribesMusicAndSoundForAccessibility$MAMediaCharacteristicDescribesVideoForAccessibility$MAMediaCharacteristicTranscribesSpokenDialogForAccessibility$kMAAudibleMediaSettingsChangedNotification$kMACaptionAppearanceSettingsChangedNotification$"""
enums = """$kMACaptionAppearanceBehaviorUseContentIfAvailable@1$kMACaptionAppearanceBehaviorUseValue@0$kMACaptionAppearanceDisplayTypeAlwaysOn@2$kMACaptionAppearanceDisplayTypeAutomatic@1$kMACaptionAppearanceDisplayTypeForcedOnly@0$kMACaptionAppearanceDomainDefault@0$kMACaptionAppearanceDomainUser@1$kMACaptionAppearanceFontStyleCasual@5$kMACaptionAppearanceFontStyleCursive@6$kMACaptionAppearanceFontStyleDefault@0$kMACaptionAppearanceFontStyleMonospacedWithSerif@1$kMACaptionAppearanceFontStyleMonospacedWithoutSerif@3$kMACaptionAppearanceFontStyleProportionalWithSerif@2$kMACaptionAppearanceFontStyleProportionalWithoutSerif@4$kMACaptionAppearanceFontStyleSmallCapital@7$kMACaptionAppearanceTextEdgeStyleDepressed@3$kMACaptionAppearanceTextEdgeStyleDropShadow@5$kMACaptionAppearanceTextEdgeStyleNone@1$kMACaptionAppearanceTextEdgeStyleRaised@2$kMACaptionAppearanceTextEdgeStyleUndefined@0$kMACaptionAppearanceTextEdgeStyleUniform@4$"""
misc.update({})
functions = {
    "MACaptionAppearanceCopyFontDescriptorForStyle": (
        b"^{__CTFontDescriptor=}q^qq",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"null_accepted": True, "type_modifier": "o"}},
        },
    ),
    "MACaptionAppearanceCopyForegroundColor": (
        b"^{CGColor=}q^q",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"null_accepted": True, "type_modifier": "o"}},
        },
    ),
    "MACaptionAppearanceCopySelectedLanguages": (
        b"^{__CFArray=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MACaptionAppearanceCopyWindowColor": (
        b"^{CGColor=}q^q",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"null_accepted": True, "type_modifier": "o"}},
        },
    ),
    "MAImageCaptioningSetCaption": (
        b"B^{__CFURL=}^{__CFString=}^^{__CFError=}",
        "",
        {
            "arguments": {
                2: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            }
        },
    ),
    "MACaptionAppearanceCopyPreferredCaptioningMediaCharacteristics": (
        b"^{__CFArray=}q",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MACaptionAppearanceGetDisplayType": (b"qq",),
    "MACaptionAppearanceGetWindowRoundedCornerRadius": (
        b"dq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MACaptionAppearanceSetDisplayType": (b"vqq",),
    "MAAudibleMediaCopyPreferredCharacteristics": (
        b"^{__CFArray=}",
        "",
        {"retval": {"already_cfretained": True}, "variadic": False},
    ),
    "MACaptionAppearanceGetRelativeCharacterSize": (
        b"dq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MAImageCaptioningCopyMetadataTagPath": (
        b"@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "MAImageCaptioningCopyCaption": (
        b"^{__CFString=}^{__CFURL=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "null_accepted": True,
                    "already_cfretained": True,
                    "type_modifier": "o",
                }
            },
        },
    ),
    "MACaptionAppearanceGetForegroundOpacity": (
        b"dq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MACaptionAppearanceCopyBackgroundColor": (
        b"^{CGColor=}q^q",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"null_accepted": True, "type_modifier": "o"}},
        },
    ),
    "MACaptionAppearanceGetBackgroundOpacity": (
        b"dq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MACaptionAppearanceGetTextEdgeStyle": (
        b"qq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MACaptionAppearanceAddSelectedLanguage": (
        b"Bq^{__CFString=}",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
    "MACaptionAppearanceDidDisplayCaptions": (b"v^{__CFArray=}",),
    "MACaptionAppearanceGetWindowOpacity": (
        b"dq^q",
        "",
        {"arguments": {1: {"null_accepted": True, "type_modifier": "o"}}},
    ),
}
expressions = {}

# END OF FILE



import MediaAccessibility
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestMAImageCaptioning(TestCase):
    @min_os_level("10.15")
    def testFunctions10_10(self):
        self.assertResultIsCFRetained(MediaAccessibility.MAImageCaptioningCopyCaption)
        self.assertArgIsOut(MediaAccessibility.MAImageCaptioningCopyCaption, 1)
        self.assertArgIsCFRetained(MediaAccessibility.MAImageCaptioningCopyCaption, 1)

        self.assertArgIsOut(MediaAccessibility.MAImageCaptioningSetCaption, 2)
        self.assertArgIsCFRetained(MediaAccessibility.MAImageCaptioningSetCaption, 2)

        self.assertResultIsCFRetained(
            MediaAccessibility.MAImageCaptioningCopyMetadataTagPath
        )



import MediaAccessibility
from PyObjCTools.TestSupport import TestCase, min_os_level
import objc


class TestMAAudibleMedia(TestCase):
    @min_os_level("10.9")
    def test_constants(self):
        self.assertIsInstance(
            MediaAccessibility.kMACaptionAppearanceSettingsChangedNotification, str
        )
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceDomainDefault, 0)
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceDomainUser, 1)

        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceDisplayTypeForcedOnly, 0
        )
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceDisplayTypeAutomatic, 1)
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceDisplayTypeAlwaysOn, 2)

        self.assertEqual(MediaAccessibility.kMACaptionAppearanceBehaviorUseValue, 0)
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceBehaviorUseContentIfAvailable, 1
        )

        self.assertEqual(MediaAccessibility.kMACaptionAppearanceFontStyleDefault, 0)
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceFontStyleMonospacedWithSerif, 1
        )
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceFontStyleProportionalWithSerif, 2
        )
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceFontStyleMonospacedWithoutSerif, 3
        )
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceFontStyleProportionalWithoutSerif, 4
        )
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceFontStyleCasual, 5)
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceFontStyleCursive, 6)
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceFontStyleSmallCapital, 7
        )

        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceTextEdgeStyleUndefined, 0
        )
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceTextEdgeStyleNone, 1)
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceTextEdgeStyleRaised, 2)
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceTextEdgeStyleDepressed, 3
        )
        self.assertEqual(MediaAccessibility.kMACaptionAppearanceTextEdgeStyleUniform, 4)
        self.assertEqual(
            MediaAccessibility.kMACaptionAppearanceTextEdgeStyleDropShadow, 5
        )

        self.assertIsInstance(
            MediaAccessibility.MAMediaCharacteristicDescribesMusicAndSoundForAccessibility,
            str,
        )
        self.assertIsInstance(
            MediaAccessibility.MAMediaCharacteristicTranscribesSpokenDialogForAccessibility,
            str,
        )

    @min_os_level("10.9")
    def test_functions(self):
        self.assertResultHasType(
            MediaAccessibility.MACaptionAppearanceAddSelectedLanguage, objc._C_BOOL
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopySelectedLanguages
        )
        self.assertIsInstance(
            MediaAccessibility.MACaptionAppearanceGetDisplayType, objc.function
        )
        self.assertIsInstance(
            MediaAccessibility.MACaptionAppearanceSetDisplayType, objc.function
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopyPreferredCaptioningMediaCharacteristics
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopyForegroundColor
        )
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceCopyForegroundColor, 1
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopyBackgroundColor
        )
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceCopyBackgroundColor, 1
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopyWindowColor
        )
        self.assertArgIsOut(MediaAccessibility.MACaptionAppearanceCopyWindowColor, 1)
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceGetForegroundOpacity, 1
        )
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceGetBackgroundOpacity, 1
        )
        self.assertArgIsOut(MediaAccessibility.MACaptionAppearanceGetWindowOpacity, 1)
        self.assertIsInstance(
            MediaAccessibility.MACaptionAppearanceGetWindowRoundedCornerRadius,
            objc.function,
        )
        self.assertResultIsCFRetained(
            MediaAccessibility.MACaptionAppearanceCopyFontDescriptorForStyle
        )
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceCopyFontDescriptorForStyle, 1
        )
        self.assertArgIsOut(
            MediaAccessibility.MACaptionAppearanceGetRelativeCharacterSize, 1
        )
        self.assertArgIsOut(MediaAccessibility.MACaptionAppearanceGetTextEdgeStyle, 1)

    @min_os_level("10.15")
    def test_functions10_15(self):
        MediaAccessibility.MACaptionAppearanceDidDisplayCaptions
